#
# This is a Shiny web application. You can run the application by clicking
# the 'Run App' button above.
#
# Find out more about building applications with Shiny here:
#
#    http://shiny.rstudio.com/
#

library(shiny)
library(tidyverse) #added
library(ggthemes)

# setwd("D:/User/Dropbox (Personal)/Education/Classes/17Fall_EPID799C_RforEpi/lectures/L21_ExampleShinyApp/shiny_birth_app")
EMM_df = read.csv("data/table2_birth_EMM_df.csv")

# Define UI for application that draws a histogram
ui <- fluidPage(
   
   # Application title
   titlePanel("Birth App"),
   
   # Sidebar with a slider input for number of bins 
   sidebarLayout(
      # Selector
      sidebarPanel(
         checkboxGroupInput("EMM", "EMM Chooser", 
                     EMM_df$model, selected = EMM_df$model)
      ),
      # Plot
      mainPanel(
         plotOutput("EMM_plot")
      )
   )
)

# Define server logic required to draw a histogram
server <- function(input, output) {

   output$EMM_plot = renderPlot({ #input = list(EMM = EMM_df$model)
     df = EMM_df[EMM_df$model %in% input$EMM,]
     df$model_number = substr(df$model, 1, 7)
     
     ggplot(df, aes(model_number, estimate,color=estimate, fill=estimate))+
       geom_linerange(aes(ymin=X2.5.., ymax=X97.5..), size=1)+
       geom_point(shape=15, size=4, color="white")+ geom_point(shape=15)+
       scale_y_continuous(limits=c(NA,NA), breaks=seq(-0.15, 0.05, 0.01))+
       geom_hline(yintercept = 0, lty=2, color="grey")+
       labs(title="Estimated effects of prenatal care on preterm birth", 
            subtitle="for selected models, modelling overall and raceeth-specific models.", 
            x = "Estimate of Risk Difference (negative = protective)")+
       ggthemes::theme_tufte()
   })
}

# Run the application 
shinyApp(ui = ui, server = server)

